@@ -79,8 +79,7 @@ lowLevelQuerySqlToAndromeda.default <- function(connection,
     "org.ohdsi.databaseConnector.BatchedQuery",
     connection@jConnection,
     query,
-    dbms(connection),
-    supportsAutoCommit(dbms(connection))
+    dbms(connection)
   )
   
   on.exit(rJava::.jcall(batchedQuery, "V", "clear"))
